if(NOT dune-grid_FOUND)
# Whether this module is installed or not
set(dune-grid_INSTALLED ON)

# Settings specific to the module

# Package initialization

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was dune-grid-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/x86_64-linux-gnu/cmake/dune-grid" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

#report other information
set_and_check(dune-grid_PREFIX "${PACKAGE_PREFIX_DIR}")
set_and_check(dune-grid_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(dune-grid_CMAKE_CONFIG_VERSION "2.10")
set(dune-grid_CXX_FLAGS "-g -O2  -fstack-protector-strong -fstack-clash-protection -Wformat -Werror=format-security -fcf-protection  -Wdate-time -D_FORTIFY_SOURCE=2")
set(dune-grid_CXX_FLAGS_DEBUG "-g")
set(dune-grid_CXX_FLAGS_MINSIZEREL "-Os -DNDEBUG")
set(dune-grid_CXX_FLAGS_RELEASE "-O3 -DNDEBUG")
set(dune-grid_CXX_FLAGS_RELWITHDEBINFO "-O2 -g -DNDEBUG")
set(dune-grid_DEPENDS "dune-geometry (>= 2.10)")
set(dune-grid_SUGGESTS "dune-uggrid (>=2.10)")
set(dune-grid_MODULE_PATH "${PACKAGE_PREFIX_DIR}/share/dune/cmake/modules")
set(dune-grid_PYTHON_WHEELHOUSE "${PACKAGE_PREFIX_DIR}/")
set(dune-grid_LIBRARIES "Dune::Grid")
set(dune-grid_HASPYTHON 1)
set(dune-grid_PYTHONREQUIRES "")

# Resolve dune dependencies
include(CMakeFindDependencyMacro)
macro(find_and_check_dune_dependency module version)
  find_dependency(${module})
  list(PREPEND CMAKE_MODULE_PATH "${dune-common_MODULE_PATH}")
  include(DuneModuleDependencies)
  list(POP_FRONT CMAKE_MODULE_PATH)
  if(dune-common_VERSION VERSION_GREATER_EQUAL "2.10")
    dune_check_module_version(${module} QUIET REQUIRED VERSION "${version}")
  endif()
endmacro()

find_and_check_dune_dependency(dune-uggrid ">=2.10")
find_and_check_dune_dependency(dune-geometry ">= 2.10")

# Set up DUNE_LIBS, DUNE_FOUND_DEPENDENCIES, DUNE_*_FOUND, and HAVE_* variables
if(dune-grid_LIBRARIES)
  message(STATUS "Setting dune-grid_LIBRARIES=${dune-grid_LIBRARIES}")
  list(PREPEND DUNE_LIBS ${dune-grid_LIBRARIES})
endif()
list(APPEND DUNE_FOUND_DEPENDENCIES dune-grid)
set(DUNE_dune-grid_FOUND TRUE)
set(HAVE_DUNE_GRID TRUE)

# Lines that are set by the CMake build system via the variable DUNE_CUSTOM_PKG_CONFIG_SECTION
#Export the directory with the grid example for downstream modules
if(dune-grid_INSTALLED)
  set_and_check(DUNE_GRID_EXAMPLE_GRIDS_PATH "${PACKAGE_PREFIX_DIR}/share/doc/dune-grid/grids/"))
else()
  set_and_check(DUNE_GRID_EXAMPLE_GRIDS_PATH "${dune-grid_PREFIX}/doc/grids/")
endif()


# If this file is found in a super build that includes dune-grid, the 
# `dune-grid-targets.cmake`-file has not yet been generated. This variable
# determines whether the configuration of dune-grid has been completed.
get_property(dune-grid_IN_CONFIG_MODE GLOBAL PROPERTY dune-grid_LIBRARIES DEFINED)

#import the target
if(dune-grid_LIBRARIES AND NOT dune-grid_IN_CONFIG_MODE)
  get_filename_component(_dir "${CMAKE_CURRENT_LIST_FILE}" PATH)
  include("${_dir}/dune-grid-targets.cmake")
endif()

endif()
